OSSP CVS Repository

ossp - Difference in ossp-pkg/as/as-gui/as_gui.h versions 1.8 and 1.9
Not logged in
[Honeypot]  [Browse]  [Home]  [Login]  [Reports
[Search]  [Ticket]  [Timeline
  [History

ossp-pkg/as/as-gui/as_gui.h 1.8 -> 1.9

--- as_gui.h     2002/11/14 22:26:30     1.8
+++ as_gui.h     2002/11/18 22:13:56     1.9
@@ -13,6 +13,9 @@
 #include <qlineedit.h>
 #include <qlayout.h>
 
+// Intentional no operation
+#define TITRAQ_NOP ((void)0)
+
 
 // Main table size
 const int g_knRows = 16;
@@ -25,7 +28,7 @@
 
 public:
     Titraqform(QWidget *pParent = 0, const char *kszName = 0, WFlags Flags = 0);
-    ~Titraqform();
+    ~Titraqform(void);
 
     // Main application actions
     QAction     *m_pFilenewact,   *m_pFileopenact;
@@ -37,10 +40,16 @@
     // Table, cells, and entries in package layout
     QTable      *m_pMaintable;
     QHeader     *m_pTablehead;
-    QImage      *m_pIconimage;
-    QPixmap     *m_pIconpixmap;
     QStringList *m_pTaskentries;
 
+    // Reusable graphics
+    QImage      *m_pOsspicon;
+    QImage      *m_pQticon;
+    QImage      *m_pNewicon;
+    QImage      *m_pOpenicon;
+    QImage      *m_pSaveicon;
+    QImage      *m_pWhatsicon;
+
     // Push buttons in control layout
     QPushButton *m_pAddbutton;
     QPushButton *m_pDeletebutton;
@@ -61,7 +70,8 @@
     void save(void);                    // Serialize to the current file
     void saveAs(void);                  // Serialize to a selected file
     void about(void);                   // Learn more about this program itself
-    void aboutQt(void);                 // Learn more about this program and Qt
+    void aboutOSSP(void);               // Learn more about the OSSP
+    void aboutQt(void);                 // Learn more about Qt
 
 protected:
     // Application main events
@@ -74,7 +84,7 @@
     QHBoxLayout *m_pControllayout;      // Lower control buttons
 
 private:
-    // Don't destroy these, they are owned by QMainWindow
+    // Owned by QMainWindow
     QMenuBar    *m_pMenubar;
     QStatusBar  *m_pStatbar;
 
@@ -87,6 +97,16 @@
 
     // Standard methods
     bool isDirty(void);                 // Check for changed state danger
+
+    // Constructor helpers
+    void setupActions(void);            // Actions
+    void setupMenubar(void);            // Menu bar
+    void setupFiletools(void);          // Tool bar
+    void setupStatusbar(void);          // Status bar
+    void setupCentralwidget(void);      // Frame widget
+    void setupTable(void);              // Table widget
+    void setupOutput(void);             // Output widget
+    void setupButtons(void);            // Push button widgets
 };
 
 #endif // TITRAQMWIN_H

CVSTrac 2.0.1